Package: TTR
Type: Package
Title: Technical Trading Rules
Version: 0.23-1
Date: 2016-03-19
Author: Joshua Ulrich
Maintainer: Joshua Ulrich <josh.m.ulrich@gmail.com>
Imports: xts (>= 0.9-3), zoo
LinkingTo: xts
Enhances: quantmod
Suggests: RUnit
Description: Functions and data to construct technical trading rules with R.
License: GPL-2
URL: https://github.com/joshuaulrich/TTR
BugReports: https://github.com/joshuaulrich/TTR/issues
NeedsCompilation: yes
Packaged: 2016-03-19 16:55:18 UTC; josh
Repository: CRAN
Date/Publication: 2016-03-21 00:06:52
Built: R 3.3.2; x86_64-w64-mingw32; 2017-05-01 20:25:45 UTC; windows
Archs: x64
