# Generated by roxygen2 (4.1.1): do not edit by hand

export(ADX)
export(ALMA)
export(ATR)
export(BBands)
export(CCI)
export(CLV)
export(CMF)
export(CMO)
export(DEMA)
export(DPO)
export(DVI)
export(DonchianChannel)
export(EMA)
export(EMV)
export(EVWMA)
export(GMMA)
export(HMA)
export(KST)
export(MACD)
export(MFI)
export(OBV)
export(PBands)
export(ROC)
export(RSI)
export(SAR)
export(SMA)
export(SMI)
export(TDI)
export(TRIX)
export(VHF)
export(VMA)
export(VWAP)
export(VWMA)
export(WMA)
export(WPR)
export(ZLEMA)
export(ZigZag)
export(adjRatios)
export(aroon)
export(chaikinAD)
export(chaikinVolatility)
export(getYahooData)
export(growth)
export(lags)
export(momentum)
export(naCheck)
export(rollSFM)
export(runCor)
export(runCov)
export(runMAD)
export(runMax)
export(runMean)
export(runMedian)
export(runMin)
export(runPercentRank)
export(runSD)
export(runSum)
export(runVar)
export(stoch)
export(stockSymbols)
export(ultimateOscillator)
export(volatility)
export(wilderSum)
export(williamsAD)
import(xts)
import(zoo)
importFrom(stats,approx)
importFrom(stats,embed)
importFrom(stats,na.omit)
importFrom(stats,sd)
importFrom(utils,flush.console)
importFrom(utils,read.csv)
importFrom(utils,read.table)
useDynLib(TTR)
